@@ -13,15 +13,28 @@ KNOWN_DATE_FORMATS = [
     "%d.%m.%Y",  # 2.1.2000
     "%Y.%m.%d",  # 2000.01.02
     "%Y/%m/%d",  # 2000/01/02
+    "%Y/%m/%d %H:%M:%S",  # 2011/06/01 01:05:01
+    "%Y/%m/%d %H:%M:%S (%z)",  # 2011/06/01 01:05:01 (+0900)
     "%Y%m%d",  # 20170209
+    "%Y%m%d %H:%M:%S",  # 20110908 14:44:51
     "%d/%m/%Y",  # 02/01/2013
     "%Y. %m. %d.",  # 2000. 01. 02.
     "%Y.%m.%d %H:%M:%S",  # 2014.03.08 10:28:24
     "%d-%b-%Y %H:%M:%S %Z",  # 24-Jul-2009 13:20:03 UTC
     "%a %b %d %H:%M:%S %Z %Y",  # Tue Jun 21 23:59:59 GMT 2011
+    "%Y-%m-%dT%H:%M:%S",  # 2007-01-26T19:10:31
     "%Y-%m-%dT%H:%M:%SZ",  # 2007-01-26T19:10:31Z
+    "%Y-%m-%dT%H:%M:%SZ[%Z]",  # 2007-01-26T19:10:31Z[UTC]
     "%Y-%m-%dT%H:%M:%S.%fZ",  # 2018-12-01T16:17:30.568Z
+    "%Y-%m-%dT%H:%M:%S.%f%z",  # 2011-09-08T14:44:51.622265+03:00
     "%Y-%m-%dT%H:%M:%S%z",  # 2013-12-06T08:17:22-0800
+    "%Y-%m-%dT%H:%M:%S%zZ",  # 1970-01-01T02:00:00+02:00Z
+    "%Y-%m-%dt%H:%M:%S.%f",  # 2011-09-08t14:44:51.622265
+    "%Y-%m-%dt%H:%M:%S",  # 2007-01-26T19:10:31
+    "%Y-%m-%dt%H:%M:%SZ",  # 2007-01-26T19:10:31Z
+    "%Y-%m-%dt%H:%M:%S.%fz",  # 2007-01-26t19:10:31.00z
+    "%Y-%m-%dt%H:%M:%S%z",  # 2011-03-30T19:36:27+0200
+    "%Y-%m-%dt%H:%M:%S.%f%z",  # 2011-09-08T14:44:51.622265+03:00
     "%Y-%m-%d %H:%M:%SZ",  # 2000-08-22 18:55:20Z
     "%Y-%m-%d %H:%M:%S",  # 2000-08-22 18:55:20
     "%d %b %Y %H:%M:%S",  # 08 Apr 2013 05:44:00
@@ -32,6 +45,8 @@ KNOWN_DATE_FORMATS = [
     "%B %d %Y",  # August 14 2017
     "%d.%m.%Y %H:%M:%S",  # 08.03.2014 10:28:24
     "%a %b %d %Y",  # Tue Dec 12 2000
+    "before %b-%Y",  # before aug-1996
+    "%Y-%m-%d %H:%M:%S (%Z%z)",  # 2017-09-26 11:38:29 (GMT+00:00)
 ]
 
 
