@@ -43,7 +43,15 @@ class Query:
         match = ""
         found = re.search(regex, blob, flags=re.IGNORECASE)
         if found:
-            match = found.group(1).rstrip("\r").replace(" ", "").rstrip(":").rstrip("/")
+            match = (
+                found.group(1)
+                .rstrip("\r")
+                .replace(" ", "")
+                .replace("http://", "")
+                .replace("https://", "")
+                .rstrip(":")
+                .rstrip("/")
+            )
         return match
 
     @contextmanager
